"""Template for SQLAlchemy models."""

MODEL_TEMPLATE = '''
"""
{{ model_name }} Model
Generated by BS FastAPI CLI
"""

from sqlalchemy import Column, Integer, String, DateTime, Boolean, Text
from sqlalchemy.sql import func
from bs__connection.database import Base

class {{ model_name }}(Base):
    __tablename__ = "{{ model_name_lower }}s"
    
    {% for field in fields -%}
    {% if field.type == 'int' -%}
    {{ field.name }} = Column(Integer, {% if field.name == 'id' %}primary_key=True, index=True{% else %}nullable=True{% endif %})
    {% elif field.type == 'str' -%}
    {{ field.name }} = Column(String, {% if field.name == 'id' %}primary_key=True, index=True{% else %}nullable=True{% endif %})
    {% elif field.type == 'bool' -%}
    {{ field.name }} = Column(Boolean, default=False)
    {% elif field.type == 'text' -%}
    {{ field.name }} = Column(Text, nullable=True)
    {% elif field.type == 'datetime' -%}
    {{ field.name }} = Column(DateTime(timezone=True), {% if field.name == 'created_at' %}server_default=func.now(){% else %}nullable=True{% endif %})
    {% else -%}
    {{ field.name }} = Column(String, nullable=True)
    {% endif %}
    {% endfor %}
    
    def __repr__(self):
        return f"<{{ model_name }}(id={self.id})>"
'''
